Index: src/images/SkImageDecoder_libpng.cpp |
diff --git a/src/images/SkImageDecoder_libpng.cpp b/src/images/SkImageDecoder_libpng.cpp |
index 47963b5543ece7d3c8224340c8c6f34056eee7c6..a03ed10453f70d8053dc72bafee1bae8f8f5ae3f 100644 |
--- a/src/images/SkImageDecoder_libpng.cpp |
+++ b/src/images/SkImageDecoder_libpng.cpp |
@@ -124,10 +124,9 @@ static void sk_read_fn(png_structp png_ptr, png_bytep data, png_size_t length) { |
#ifdef PNG_READ_UNKNOWN_CHUNKS_SUPPORTED |
static int sk_read_user_chunk(png_structp png_ptr, png_unknown_chunkp chunk) { |
- SkImageDecoder::Peeker* peeker = |
- (SkImageDecoder::Peeker*)png_get_user_chunk_ptr(png_ptr); |
- // peek() returning true means continue decoding |
- return peeker->peek((const char*)chunk->name, chunk->data, chunk->size) ? |
+ SkPngChunkReader* peeker = (SkPngChunkReader*)png_get_user_chunk_ptr(png_ptr); |
+ // readChunk() returning true means continue decoding |
+ return peeker->readChunk((const char*)chunk->name, chunk->data, chunk->size) ? |
1 : -1; |
} |
#endif |